nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

PrinceBaseAddr

Struct PrinceBaseAddr 

#[repr(transparent)]
pub struct PrinceBaseAddr(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl PrinceBaseAddr

pub const fn addr0_prg(&self) -> u8

Programmable portion of the base address of region 0

pub const fn set_addr0_prg(&mut self, val: u8)

Programmable portion of the base address of region 0

pub const fn addr1_prg(&self) -> u8

Programmable portion of the base address of region 1

pub const fn set_addr1_prg(&mut self, val: u8)

Programmable portion of the base address of region 1

pub const fn addr2_prg(&self) -> u8

Programmable portion of the base address of region 2

pub const fn set_addr2_prg(&mut self, val: u8)

Programmable portion of the base address of region 2

pub const fn lock_reg0(&self) -> LockReg0

Lock PRINCE region0 settings

pub const fn set_lock_reg0(&mut self, val: LockReg0)

Lock PRINCE region0 settings

pub const fn lock_reg1(&self) -> LockReg1

Lock PRINCE region1 settings

pub const fn set_lock_reg1(&mut self, val: LockReg1)

Lock PRINCE region1 settings

pub const fn reg0_erase_check_en(&self) -> Reg0EraseCheckEn

For PRINCE region0 enable checking whether all encrypted pages are erased together

pub const fn set_reg0_erase_check_en(&mut self, val: Reg0EraseCheckEn)

For PRINCE region0 enable checking whether all encrypted pages are erased together

pub const fn reg1_erase_check_en(&self) -> Reg1EraseCheckEn

For PRINCE region1 enable checking whether all encrypted pages are erased together

pub const fn set_reg1_erase_check_en(&mut self, val: Reg1EraseCheckEn)

For PRINCE region1 enable checking whether all encrypted pages are erased together

pub const fn reg2_erase_check_en(&self) -> Reg2EraseCheckEn

For PRINCE region2 enable checking whether all encrypted pages are erased together

pub const fn set_reg2_erase_check_en(&mut self, val: Reg2EraseCheckEn)

For PRINCE region2 enable checking whether all encrypted pages are erased together